@@ -428,13 +428,13 @@ autotest_kernel <- function(kern, shortname, support, variance, pdfSquared2Norm,
 
   # context("d/p/q/r")
   if (isPdf(kern)) {
-    expect_rounded_equal(kern$pdf(c(-0.1, 0, 0.1)), pdf)
+    expect_rounded_equal(kern$pdf(c(-0.1, 0, 0.1)), pdf, 3)
     if (kern$.__enclos_env__$private$.log) {
       expect_rounded_equal(kern$pdf(c(-0.1, 0, 0.1), log = TRUE), log(pdf), 2)
     }
   }
   if (isCdf(kern)) {
-    expect_rounded_equal(kern$cdf(c(-0.1, 0, 0.1)), cdf)
+    expect_rounded_equal(kern$cdf(c(-0.1, 0, 0.1)), cdf, 3)
     if (kern$.__enclos_env__$private$.log) {
       expect_rounded_equal(kern$cdf(c(-0.1, 0, 0.1), lower.tail = FALSE, log.p = TRUE),
                            log(1 - cdf), 3)
