@@ -53,14 +53,14 @@ test_that("one row", {
 
   avd <- VectorDistribution$new(
     distribution = "Arcsine",
-    params = data.table(lower = -(2:3), upper = 4:5)
+    params = data.table(lower = c(-2, -3), upper = 4:5)
   )
 
   expect_equal(as.numeric(unlist(avd$pdf(data = matrix(1:2, nrow = 1)))),
               c(Arcsine$new(-2, 4)$pdf(1), Arcsine$new(-3, 5)$pdf(2)))
   expect_equal(as.numeric(unlist(avd$cdf(data = matrix(1:2, nrow = 1)))),
                c(Arcsine$new(-2, 4)$cdf(1), Arcsine$new(-3, 5)$cdf(2)))
-  expect_equal(as.numeric(unlist(avd$quantile(data = matrix(c(0.1,0.2), nrow = 1)))),
+  expect_equal(as.numeric(unlist(avd$quantile(data = matrix(c(0.1, 0.2), nrow = 1)))),
                c(Arcsine$new(-2, 4)$quantile(0.1), Arcsine$new(-3, 5)$quantile(0.2)))
 })
 
@@ -402,8 +402,8 @@ test_that("median", {
 })
 
 test_that("custom single row", {
-  v <- VectorDistribution$new(distribution = "Arcsine", params = data.frame(upper = (1:10)+10))
+  v <- VectorDistribution$new(distribution = "Arcsine", params = data.frame(upper = (1:10) + 10))
   p1 <- v$pdf(data = matrix(1:10, nrow = 1))
-  p2 <- sapply((1:10)+10, function(x) Arcsine$new(upper = x)$pdf(x-10))
+  p2 <- sapply((1:10) + 10, function(x) Arcsine$new(upper = x)$pdf(x - 10))
   expect_equal(as.numeric(unlist(p1)), p2)
 })
